@@ -35,10 +35,6 @@ struct KdeConnectConfigPrivate {
 
     QSettings *m_config;
     QSettings *m_trustedDevices;
-
-#ifdef Q_OS_MAC
-    QString m_privateDBusAddress; // Private DBus Address cache
-#endif
 };
 
 static QString getDefaultDeviceName()
@@ -80,6 +76,17 @@ void KdeConnectConfig::setName(const QString &name)
     d->m_config->sync();
 }
 
+void KdeConnectConfig::setDisabledLinkProviders(const QStringList disabledProviders)
+{
+    d->m_config->setValue(QStringLiteral("disabled_providers"), disabledProviders);
+    d->m_config->sync();
+}
+
+QStringList KdeConnectConfig::disabledLinkProviders() const
+{
+    return d->m_config->value(QStringLiteral("disabled_providers")).toStringList();
+}
+
 DeviceType KdeConnectConfig::deviceType()
 {
     const QByteArrayList platforms = qgetenv("PLASMA_PLATFORM").split(':');
@@ -163,6 +170,7 @@ void KdeConnectConfig::addTrustedDevice(const DeviceInfo &deviceInfo)
     d->m_trustedDevices->beginGroup(deviceInfo.id);
     d->m_trustedDevices->setValue(QStringLiteral("name"), deviceInfo.name);
     d->m_trustedDevices->setValue(QStringLiteral("type"), deviceInfo.type.toString());
+    d->m_trustedDevices->setValue(QStringLiteral("protocolVersion"), deviceInfo.protocolVersion);
     QString certString = QString::fromLatin1(deviceInfo.certificate.toPem());
     d->m_trustedDevices->setValue(QStringLiteral("certificate"), certString);
     d->m_trustedDevices->endGroup();
@@ -181,6 +189,7 @@ void KdeConnectConfig::updateTrustedDeviceInfo(const DeviceInfo &deviceInfo)
     d->m_trustedDevices->beginGroup(deviceInfo.id);
     d->m_trustedDevices->setValue(QStringLiteral("name"), deviceInfo.name);
     d->m_trustedDevices->setValue(QStringLiteral("type"), deviceInfo.type.toString());
+    d->m_trustedDevices->setValue(QStringLiteral("protocolVersion"), deviceInfo.protocolVersion);
     d->m_trustedDevices->endGroup();
     d->m_trustedDevices->sync();
 }
@@ -193,6 +202,14 @@ QSslCertificate KdeConnectConfig::getTrustedDeviceCertificate(const QString &id)
     return QSslCertificate(certString.toLatin1());
 }
 
+int KdeConnectConfig::getTrustedDeviceProtocolVersion(const QString &id)
+{
+    d->m_trustedDevices->beginGroup(id);
+    int protocolVersion = d->m_trustedDevices->value(QStringLiteral("protocolVersion"), 0).toInt();
+    d->m_trustedDevices->endGroup();
+    return protocolVersion;
+}
+
 DeviceInfo KdeConnectConfig::getTrustedDevice(const QString &id)
 {
     d->m_trustedDevices->beginGroup(id);
@@ -215,6 +232,12 @@ void KdeConnectConfig::removeTrustedDevice(const QString &deviceId)
     // We do not remove the config files.
 }
 
+void KdeConnectConfig::removeAllTrustedDevices()
+{
+    d->m_trustedDevices->clear();
+    d->m_trustedDevices->sync();
+}
+
 // Utility functions to set and get a value
 void KdeConnectConfig::setDeviceProperty(const QString &deviceId, const QString &key, const QString &value)
 {
@@ -276,10 +299,18 @@ bool KdeConnectConfig::loadPrivateKey(const QString &keyPath)
 bool KdeConnectConfig::loadCertificate(const QString &certPath)
 {
     QFile cert(certPath);
+    QDateTime now = QDateTime::currentDateTime();
+
     if (cert.exists() && cert.open(QIODevice::ReadOnly)) {
         d->m_certificate = QSslCertificate(cert.readAll());
         if (d->m_certificate.isNull()) {
             qCWarning(KDECONNECT_CORE) << "Certificate from" << certPath << "is not valid";
+        } else if (d->m_certificate.effectiveDate() >= now) {
+            qCWarning(KDECONNECT_CORE) << "Certificate from" << certPath << "not yet effective: " << d->m_certificate.effectiveDate();
+            return true;
+        } else if (d->m_certificate.expiryDate() <= now) {
+            qCWarning(KDECONNECT_CORE) << "Certificate from" << certPath << "expired: " << d->m_certificate.expiryDate();
+            return true;
         }
     }
     return d->m_certificate.isNull();
@@ -294,6 +325,7 @@ void KdeConnectConfig::loadOrGeneratePrivateKeyAndCertificate(const QString &key
         generatePrivateKey(keyPath);
     }
     if (needsToGenerateCert) {
+        removeAllTrustedDevices();
         generateCertificate(certPath);
     }
 
@@ -340,7 +372,7 @@ void KdeConnectConfig::generateCertificate(const QString &certPath)
 {
     qCDebug(KDECONNECT_CORE) << "Generating certificate";
 
-    QString uuid = QUuid::createUuid().toString();
+    QString uuid = QUuid::createUuid().toString(QUuid::WithoutBraces).toLower();
     DBusHelper::filterNonExportableCharacters(uuid);
     qCDebug(KDECONNECT_CORE) << "My id:" << uuid;
 
@@ -366,48 +398,3 @@ void KdeConnectConfig::generateCertificate(const QString &certPath)
         Daemon::instance()->reportError(QStringLiteral("KDE Connect"), i18n("Could not store certificate file: %1", certPath));
     }
 }
-
-#ifdef Q_OS_MAC
-QString KdeConnectConfig::privateDBusAddressPath()
-{
-    return baseConfigDir().absoluteFilePath(QStringLiteral("private_dbus_address"));
-}
-
-QString KdeConnectConfig::privateDBusAddress()
-{
-    if (d->m_privateDBusAddress.length() != 0)
-        return d->m_privateDBusAddress;
-
-    QString dbusAddressPath = privateDBusAddressPath();
-    QFile dbusAddressFile(dbusAddressPath);
-
-    if (!dbusAddressFile.open(QFile::ReadOnly | QFile::Text)) {
-        qCCritical(KDECONNECT_CORE) << "Private DBus enabled but error read private dbus address conf";
-        exit(1);
-    }
-
-    QTextStream in(&dbusAddressFile);
-
-    qCDebug(KDECONNECT_CORE) << "Waiting for private dbus";
-
-    int retry = 0;
-    QString addr = in.readLine();
-    while (addr.length() == 0 && retry < 5) {
-        qCDebug(KDECONNECT_CORE) << "Retry reading private DBus address after 3s";
-        QThread::sleep(3);
-        retry++;
-        addr = in.readLine(); // Read until first not empty line
-    }
-
-    if (addr.length() == 0) {
-        qCCritical(KDECONNECT_CORE) << "Private DBus enabled but read private dbus address failed";
-        exit(1);
-    }
-
-    qCDebug(KDECONNECT_CORE) << "Private dbus address: " << addr;
-
-    d->m_privateDBusAddress = addr;
-
-    return addr;
-}
-#endif
