@@ -35,7 +35,6 @@ public:
         , _cRef(1)
     {
     }
-    ~CAudioEndpointVolumeCallback(){};
 
     // IUnknown methods -- AddRef, Release, and QueryInterface
 
@@ -91,9 +90,9 @@ class SystemvolumePlugin::CMMNotificationClient : public IMMNotificationClient
 public:
     CMMNotificationClient(SystemvolumePlugin &x)
         : enclosing(x)
-        , _cRef(1){};
-
-    ~CMMNotificationClient(){};
+        , _cRef(1)
+    {
+    }
 
     // IUnknown methods -- AddRef, Release, and QueryInterface
 
@@ -204,12 +203,9 @@ public:
         // This callback is supper spammy. Care only about name and description changes.
         if (IsEqualPropertyKey(key, PKEY_Device_FriendlyName)) {
             enclosing.sendSinkList();
-        }
-#ifndef __MINGW32__
-        else if (IsEqualPropertyKey(key, PKEY_Device_DeviceDesc)) {
+        } else if (IsEqualPropertyKey(key, PKEY_Device_DeviceDesc)) {
             enclosing.sendSinkList();
         }
-#endif
         return S_OK;
     }
 
@@ -303,13 +299,9 @@ bool SystemvolumePlugin::sendSinkList()
         name = QString::fromWCharArray(deviceProperty.pwszVal);
         PropVariantClear(&deviceProperty);
 
-#ifndef __MINGW32__
         deviceProperties->GetValue(PKEY_Device_DeviceDesc, &deviceProperty);
         desc = QString::fromWCharArray(deviceProperty.pwszVal);
         PropVariantClear(&deviceProperty);
-#else
-        desc = name;
-#endif
 
         QJsonObject sinkObject;
         sinkObject.insert(QStringLiteral("name"), name);
